/*
 * Copyright 2016 - 2021 gary@drinkingtea.net
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#pragma once

#include <ox/event/signal.hpp>
#include <ox/std/memory.hpp>
#include <ox/std/string.hpp>

#include "lib/module.hpp"
#include "lib/project.hpp"
#include "lib/task.hpp"
#include "projectexplorer.hpp"
#include "projecttreemodel.hpp"

namespace nostalgia {

class StudioUI: public ox::SignalHandler {
	friend class StudioUIDrawer;

	private:
		ox::UniquePtr<studio::Project> m_project;
		studio::TaskRunner m_taskRunner;
		core::Context *m_ctx = nullptr;
		ox::Vector<ox::UniquePtr<studio::Editor>> m_editors;
		ox::Vector<ox::UniquePtr<studio::Widget>> m_widgets;
		ox::HashMap<ox::String, studio::EditorMaker::Func> m_editorMakers;
		ProjectExplorer *m_projectExplorer = nullptr;
		ox::Vector<ox::String> m_openFiles;
		bool m_saveEnabled = false;
		bool m_aboutEnabled = false;

	public:
		explicit StudioUI(core::Context *ctx) noexcept;

		void update() noexcept;

	protected:
		void draw() noexcept;

	private:
		void drawMenu() noexcept;

		void drawToolbar() noexcept;

		void drawTabs() noexcept;

		void loadEditorMaker(const studio::EditorMaker &editorMaker) noexcept;

		void loadModule(studio::Module *module) noexcept;

		void loadModules() noexcept;

		ox::Error openProject(const ox::String &path) noexcept;

		ox::Error openFile(const ox::String &path) noexcept;

		ox::Error closeFile(const ox::String &path) noexcept;
};

}